==> haskell-lazysmallcheck-0.6-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lazysmallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lazysmallcheck
version:              0.6
visibility:           public
id:                   lazysmallcheck-0.6-IFdnbuYmhkmEQtFy7QHeNo
key:                  lazysmallcheck-0.6-IFdnbuYmhkmEQtFy7QHeNo
license:              BSD-3-Clause
maintainer:           Matthew Naylor <mfn@cs.york.ac.uk>
author:               Matthew Naylor and Fredrik Lindblad
homepage:             http://www.cs.york.ac.uk/~mfn/lazysmallcheck/
synopsis:             A library for demand-driven testing of Haskell programs
description:
    Lazy SmallCheck is a library for exhaustive, demand-driven testing of
    Haskell programs.  It is based on the idea that if a property holds
    for a partially-defined input then it must also hold for all
    fully-defined refinements of the that input.  Compared to ``eager'\'''\''
    input generation as in SmallCheck, Lazy SmallCheck may require
    significantly fewer test-cases to verify a property for all inputs up
    to a given depth.

category:             Testing
abi:                  5fb9c1d205762252c82865c862ff5bfb
exposed:              True
exposed-modules:      Test.LazySmallCheck
import-dirs:          /usr/lib/ghc-9.0.1/site-local/lazysmallcheck-0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lazysmallcheck-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lazysmallcheck-0.6
hs-libraries:         HSlazysmallcheck-0.6-IFdnbuYmhkmEQtFy7QHeNo
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-lazysmallcheck/html/lazysmallcheck.haddock

haddock-html:         /usr/share/doc/haskell-lazysmallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lazysmallcheck-0.6-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lazysmallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lazysmallcheck
version:              0.6
visibility:           public
id:                   lazysmallcheck-0.6-7a6d9xZ9chG3eyNv7XLsB
key:                  lazysmallcheck-0.6-7a6d9xZ9chG3eyNv7XLsB
license:              BSD-3-Clause
maintainer:           Matthew Naylor <mfn@cs.york.ac.uk>
author:               Matthew Naylor and Fredrik Lindblad
homepage:             http://www.cs.york.ac.uk/~mfn/lazysmallcheck/
synopsis:             A library for demand-driven testing of Haskell programs
description:
    Lazy SmallCheck is a library for exhaustive, demand-driven testing of
    Haskell programs.  It is based on the idea that if a property holds
    for a partially-defined input then it must also hold for all
    fully-defined refinements of the that input.  Compared to ``eager'\'''\''
    input generation as in SmallCheck, Lazy SmallCheck may require
    significantly fewer test-cases to verify a property for all inputs up
    to a given depth.

category:             Testing
abi:                  7fddd796498a3f2ba79646d4f3a50de9
exposed:              True
exposed-modules:      Test.LazySmallCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lazysmallcheck-0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lazysmallcheck-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lazysmallcheck
hs-libraries:         HSlazysmallcheck-0.6-7a6d9xZ9chG3eyNv7XLsB
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-lazysmallcheck/html/lazysmallcheck.haddock

haddock-html:         /usr/share/doc/haskell-lazysmallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
